@@ -12,7 +12,7 @@ our @EXPORT = qw(
   check_lib
   check_lib_or_exit
   find_lib_or_exit
-  find_lib_or_die 
+  find_lib_or_die
 );
 
 our @EXPORT_OK = qw(
@@ -22,7 +22,7 @@ our @EXPORT_OK = qw(
 );
 
 # ABSTRACT: Check that a library is available for FFI
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 
 our $system_path = [];
@@ -61,7 +61,7 @@ elsif($os eq 'msys')
 }
 elsif($os eq 'MSWin32')
 {
-  $pattern = [ qr{^(?:lib)?(.*?)(?:-([0-9])+)?\.dll$} ];
+  $pattern = [ qr{^(?:lib)?(.*?)(?:-([0-9])+)?\.dll$}i ];
 }
 elsif($os eq 'darwin')
 {
@@ -77,7 +77,7 @@ sub _matches
       $1,                                      # 0    capture group 1 library name
       File::Spec->catfile($path, $filename),   # 1    full path to library
       defined $2 ? (split /\./, $2) : (),      # 2... capture group 2 library version
-    ] if $filename =~ $regex; 
+    ] if $filename =~ $regex;
   }
   return ();
 }
@@ -105,7 +105,7 @@ my $diagnostic;
 sub find_lib
 {
   my(%args) = @_;
-  
+
   undef $diagnostic;
   croak "find_lib requires lib argument" unless defined $args{lib};
 
@@ -124,23 +124,23 @@ sub find_lib
       $args{$arg} = [];
     }
   }
-  
+
   if(defined $args{systempath} && !ref($args{systempath}))
   {
     $args{systempath} = [ $args{systempath} ];
   }
-  
+
   my @path = @{ $args{libpath} };
   @path = map { _recurse($_) } @path if $recursive;
   push @path, grep { defined } defined $args{systempath}
     ? @{ $args{systempath} }
     : @$system_path;
-  
+
   my $any = 1 if grep { $_ eq '*' } @{ $args{lib} };
   my %missing = map { $_ => 1 } @{ $args{lib} };
   my %symbols = map { $_ => 1 } @{ $args{symbol} };
   my @found;
-  
+
   delete $missing{'*'};
 
   foreach my $path (@path)
@@ -148,7 +148,7 @@ sub find_lib
     next unless -d $path;
     my $dh;
     opendir $dh, $path;
-    my @maybe = 
+    my @maybe =
       # make determinist based on names and versions
       sort { _cmp($a,$b) }
       # Filter out the items that do not match the name that we are looking for
@@ -156,7 +156,7 @@ sub find_lib
       grep { ($any || $missing{$_->[0]} ) && (-e $_->[1]) }
       # get [ name, full_path ] mapping,
       # each entry is a 2 element list ref
-      map { _matches($_,$path) } 
+      map { _matches($_,$path) }
       # read all files from the directory
       readdir $dh;
     closedir $dh;
@@ -165,12 +165,12 @@ sub find_lib
     foreach my $lib (@maybe)
     {
       next unless $any || $missing{$lib->[0]};
-      
+
       foreach my $verify (@{ $args{verify} })
       {
         next midloop unless $verify->(@$lib);
       }
-      
+
       delete $missing{$lib->[0]};
 
       if(%symbols)
@@ -186,9 +186,9 @@ sub find_lib
         }
         DynaLoader::dl_unload_file($dll);
       }
-      
+
       my $found = $lib->[1];
-      
+
       unless($any)
       {
         while(-l $found)
@@ -199,9 +199,9 @@ sub find_lib
           $found = File::Spec->rel2abs( readlink($found), $dir );
         }
       }
-      
+
       push @found, $found;
-    }    
+    }
   }
 
   if(%missing)
@@ -220,7 +220,7 @@ sub find_lib
     else
     { $diagnostic = "symbol not found: @missing" }
   }
-  
+
   return if %symbols;
   return $found[0] unless wantarray;
   return @found;
@@ -320,10 +320,16 @@ sub has_symbols
   }
 
   DynaLoader::dl_unload_file($dll);
-  
+
   $ok;
 }
 
+
+sub system_path
+{
+  $system_path;
+}
+
 1;
 
 __END__
@@ -338,31 +344,31 @@ FFI::CheckLib - Check that a library is available for FFI
 
 =head1 VERSION
 
-version 0.19
+version 0.22
 
 =head1 SYNOPSIS
 
-  use FFI::CheckLib;
-  
-  check_lib_or_exit( lib => 'jpeg', symbol => 'jinit_memory_mgr' );
-  check_lib_or_exit( lib => [ 'iconv', 'jpeg' ] );
-  
-  # or prompt for path to library and then:
-  print "where to find jpeg library: ";
-  my $path = <STDIN>;
-  check_lib_or_exit( lib => 'jpeg', libpath => $path );
+ use FFI::CheckLib;
+ 
+ check_lib_or_exit( lib => 'jpeg', symbol => 'jinit_memory_mgr' );
+ check_lib_or_exit( lib => [ 'iconv', 'jpeg' ] );
+ 
+ # or prompt for path to library and then:
+ print "where to find jpeg library: ";
+ my $path = <STDIN>;
+ check_lib_or_exit( lib => 'jpeg', libpath => $path );
 
 =head1 DESCRIPTION
 
-This module checks whether a particular dynamic library is available for 
-FFI to use. It is modeled heavily on L<Devel::CheckLib>, but will find 
-dynamic libraries even when development packages are not installed.  It 
-also provides a L<find_lib|FFI::CheckLib#find_lib> function that will 
-return the full path to the found dynamic library, which can be feed 
-directly into L<FFI::Platypus> or L<FFI::Raw>.
+This module checks whether a particular dynamic library is available for
+FFI to use. It is modeled heavily on L<Devel::CheckLib>, but will find
+dynamic libraries even when development packages are not installed.  It
+also provides a L<find_lib|FFI::CheckLib#find_lib> function that will
+return the full path to the found dynamic library, which can be feed
+directly into L<FFI::Platypus> or another FFI system.
 
-Although intended mainly for FFI modules via L<FFI::Platypus> and 
-similar, this module does not actually use any FFI to do its detection 
+Although intended mainly for FFI modules via L<FFI::Platypus> and
+similar, this module does not actually use any FFI to do its detection
 and probing.  This module does not have any non-core runtime dependencies.
 The test suite does depend on L<Test2::Suite>.
 
@@ -374,7 +380,7 @@ All of these take the same named parameters and are exported by default.
 
  my(@libs) = find_lib(%args);
 
-This will return a list of dynamic libraries, or empty list if none were 
+This will return a list of dynamic libraries, or empty list if none were
 found.
 
 [version 0.05]
@@ -387,9 +393,9 @@ Arguments are key value pairs with these keys:
 
 =item lib
 
-Must be either a string with the name of a single library or a reference 
-to an array of strings of library names.  Depending on your platform, 
-C<CheckLib> will prepend C<lib> or append C<.dll> or C<.so> when 
+Must be either a string with the name of a single library or a reference
+to an array of strings of library names.  Depending on your platform,
+C<CheckLib> will prepend C<lib> or append C<.dll> or C<.so> when
 searching.
 
 [version 0.11]
@@ -404,8 +410,8 @@ A string or array of additional paths to search for libraries.
 
 [version 0.11]
 
-A string or array of system paths to search for instead of letting 
-L<FFI::CheckLib> determine the system path.  You can set this to C<[]> 
+A string or array of system paths to search for instead of letting
+L<FFI::CheckLib> determine the system path.  You can set this to C<[]>
 in order to not search I<any> system paths.
 
 =item symbol
@@ -414,18 +420,18 @@ A string or a list of symbol names that must be found.
 
 =item verify
 
-A code reference used to verify a library really is the one that you 
-want.  It should take two arguments, which is the name of the library 
-and the full path to the library pathname.  It should return true if it 
-is acceptable, and false otherwise.  You can use this in conjunction 
-with L<FFI::Platypus> to determine if it is going to meet your needs.  
+A code reference used to verify a library really is the one that you
+want.  It should take two arguments, which is the name of the library
+and the full path to the library pathname.  It should return true if it
+is acceptable, and false otherwise.  You can use this in conjunction
+with L<FFI::Platypus> to determine if it is going to meet your needs.
 Example:
 
  use FFI::CheckLib;
  use FFI::Platypus;
  
  my($lib) = find_lib(
-   name => 'foo',
+   lib => 'foo',
    verify => sub {
      my($name, $libpath) = @_;
      
@@ -442,7 +448,7 @@ Example:
 
 [version 0.11]
 
-Recursively search for libraries in any non-system paths (those provided 
+Recursively search for libraries in any non-system paths (those provided
 via C<libpath> above).
 
 =back
@@ -451,17 +457,17 @@ via C<libpath> above).
 
  assert_lib(%args);
 
-This behaves exactly the same as L<find_lib|FFI::CheckLib#find_lib>, 
-except that instead of returning empty list of failure it throws an 
+This behaves exactly the same as L<find_lib|FFI::CheckLib#find_lib>,
+except that instead of returning empty list of failure it throws an
 exception.
 
 =head2 check_lib_or_exit
 
  check_lib_or_exit(%args);
 
-This behaves exactly the same as L<assert_lib|FFI::CheckLib#assert_lib>, 
-except that instead of dying, it warns (with exactly the same error 
-message) and exists.  This is intended for use in C<Makefile.PL> or 
+This behaves exactly the same as L<assert_lib|FFI::CheckLib#assert_lib>,
+except that instead of dying, it warns (with exactly the same error
+message) and exists.  This is intended for use in C<Makefile.PL> or
 C<Build.PL>
 
 =head2 find_lib_or_exit
@@ -470,8 +476,8 @@ C<Build.PL>
 
  my(@libs) = find_lib_or_exit(%args);
 
-This behaves exactly the same as L<find_lib|FFI::CheckLib#find_lib>, 
-except that if the library is not found, it will call exit with an 
+This behaves exactly the same as L<find_lib|FFI::CheckLib#find_lib>,
+except that if the library is not found, it will call exit with an
 appropriate diagnostic.
 
 =head2 find_lib_or_die
@@ -480,16 +486,16 @@ appropriate diagnostic.
 
  my(@libs) = find_lib_or_die(%args);
 
-This behaves exactly the same as L<find_lib|FFI::CheckLib#find_lib>, 
-except that if the library is not found, it will die with an appropriate 
+This behaves exactly the same as L<find_lib|FFI::CheckLib#find_lib>,
+except that if the library is not found, it will die with an appropriate
 diagnostic.
 
 =head2 check_lib
 
  my $bool = check_lib(%args);
 
-This behaves exactly the same as L<find_lib|FFI::CheckLib#find_lib>, 
-except that it returns true (1) on finding the appropriate libraries or 
+This behaves exactly the same as L<find_lib|FFI::CheckLib#find_lib>,
+except that it returns true (1) on finding the appropriate libraries or
 false (0) otherwise.
 
 =head2 which
@@ -524,6 +530,19 @@ above.
 
 Not exported by default.
 
+=head2 system_path
+
+[version 0.20]
+
+ my $path = FFI::CheckLib::system_path;
+
+Returns the system path as a list reference.  On some systems, this is C<PATH>
+on others it might be L<LD_LIBRARY_PATH> on still others it could be something
+completely different.  So although you I<may> add items to this list, you should
+probably do some careful consideration before you do so.
+
+This function is not exportable, even on request.
+
 =head1 SEE ALSO
 
 =over 4
@@ -548,9 +567,11 @@ Bakkiaraj Murugesan (bakkiaraj)
 
 Dan Book (grinnz, DBOOK)
 
+Ilya Pavlov (Ilya, ILUX)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Graham Ollis.
+This software is copyright (c) 2014-2018 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
